using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Diagnostics;
using System.Data;
using System.Windows.Forms;
using Microsoft.DataTransformationServices.Controls;
using Microsoft.SqlServer.Dts.Design;
using Microsoft.SqlServer.Dts.Runtime;
using SSIS2K5.Samples.Tasks.ExpressionTask;

namespace SSIS2K5.Samples.Tasks.ExpressionTask
{
	/// <summary>
	/// Summary description for GeneralView.
	/// </summary>
	public class GeneralView : System.Windows.Forms.UserControl,IDTSTaskUIView
	{
		#region private members
		private GeneralNode generalNode = null;

		private System.Windows.Forms.PropertyGrid propertyGrid;

        /// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		#endregion private members

		#region Init and Dispose
		public GeneralView()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		#endregion Init and Dispose

		#region IDTSTaskUIView
		/// <summary>
		/// Called when the view is about to be displayed for the first time
		/// </summary>
		/// <param name="treeHost">IDTSTaskUIHost that host the view</param>
		/// <param name="taskHost">the task that is edited by TaskUI</param>
		/// <param name="viewNode">the node in the tree associated with this view</param>
		public virtual void OnInitialize(IDTSTaskUIHost treeHost, System.Windows.Forms.TreeNode viewNode, object taskHost, object connections)
		{
			this.generalNode = new GeneralNode(taskHost as TaskHost);

			propertyGrid.SelectedObject = this.generalNode;
		}

		/// <summary>
		/// is called when the OK button is pressed
		/// </summary>
		/// <param name="bViewIsValid">result of view validation</param>
		public virtual void OnValidate(ref bool bViewIsValid, ref string reason)
		{
		}

		/// <summary>
		/// called whenever the view is displaying
		/// </summary>
		public virtual void OnSelection()
		{
		}

		/// <summary>
		/// called every time the view is about to be left.
		/// </summary>
		/// <param name="bCanLeaveView">true if the view can be left</param>
		public virtual void OnLoseSelection(ref bool bCanLeaveView, ref string reason)
		{
		}

		/// <summary>
		/// called when OK button is pushed, but only if all OnValidate calls succeeded
		/// the user should set whatever properties need to be set to the task by this view
		/// </summary>
		/// <param name="taskHost">the edited task.</param>
		public virtual void OnCommit(object taskHost)
		{
		}
		#endregion IDTSTaskUIView

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(GeneralView));
			this.propertyGrid = new System.Windows.Forms.PropertyGrid();
            this.SuspendLayout();
// 
// propertyGrid
// 
            resources.ApplyResources(this.propertyGrid, "propertyGrid");
            this.propertyGrid.SelectedObject = null;
            this.propertyGrid.Name = "propertyGrid";
            this.propertyGrid.PropertySort = System.Windows.Forms.PropertySort.Categorized;
            this.propertyGrid.ToolbarVisible = false;
// 
// GeneralView
// 
            this.Controls.Add(this.propertyGrid);
            this.Name = "GeneralView";
            resources.ApplyResources(this, "$this");
            this.ResumeLayout(false);

        }
		#endregion

	}

	#region General Node

	/// <summary>
	/// General Node class corresponds to the view that is displayed when
	/// the user clicks the General node.
	/// </summary>
	internal class GeneralNode
	{
		internal TaskHost taskHost= null;
		private SSIS2K5.Samples.Tasks.ExpressionTask.ExpressionTask expressionTask = null;

		#region Initialization

		public GeneralNode(TaskHost taskHost)
		{
			this.taskHost = taskHost;
			this.expressionTask = taskHost.InnerObject as Tasks.ExpressionTask.ExpressionTask;
		}

		#endregion

		#region Properties of GeneralNode class

		[
		Category("General"),
		Description("Specifies the name of the task.")
		]
		public string Name
		{
			get { return taskHost.Name; }
			set
			{
				if ((value == null) || (value.Trim().Length == 0))
				{
					throw new ApplicationException("Task name cannot be empty");
				}

				taskHost.Name = value;
			}
		}

		[
		Category("General"),
		Description("Specifies the description for this task.")
		]
		public string Description
		{
			get { return taskHost.Description; }
			set { taskHost.Description = value; }
		}

		[
		Category("Custom Properties"),
		Description("Contains the expression that is going to be evaluated by the task."),
		Editor( typeof(ExpressionEditor), typeof(System.Drawing.Design.UITypeEditor))
		]
		public string Expression
		{
			get { return expressionTask.Expression; }
			set { expressionTask.Expression = value; }
		}

		#endregion Properties of GeneralNode class
	}

	#endregion General Node

}
