using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.SqlServer.Dts.Runtime.Wrapper;
using Microsoft.SqlServer.Dts.Pipeline;

// Profile Min and Max for Byte, Int and Decimal types
namespace SSIS2K8.Samples.Transforms.DataProfiler
{
    #region Min and max classes for different types

    public class MinInt : ValueProfiler
    {
        private int MinValue = int.MaxValue;

        public override void Profile(object o)
        {
            int value = (int)o;
            if (value < MinValue)
                MinValue = value;
        }

        public override string GetValue() { return MinValue.ToString(); }
    }

    public class MinByte : ValueProfiler
    {
        private byte MinValue = byte.MaxValue;

        public override void Profile(object o)
        {
            byte value = (byte)o;
            if (value < MinValue)
                MinValue = value;
        }

        public override string GetValue() { return MinValue.ToString(); }
    }

    public class MinDecimal : ValueProfiler
    {
        private Decimal MinValue = Decimal.MaxValue;

        public override void Profile(object o)
        {
            Decimal value = (Decimal)o;
            if (value < MinValue)
                MinValue = value;
        }

        public override string GetValue() { return MinValue.ToString(); }
    }

    public class MaxInt : ValueProfiler
    {
        private int MaxValue = int.MinValue;

        public override void Profile(object o)
        {
            int value = (int)o;
            if (value > MaxValue)
                MaxValue = value;
        }

        public override string GetValue() { return MaxValue.ToString(); }
    }

    public class MaxByte : ValueProfiler
    {
        private byte MaxValue = byte.MinValue;

        public override void Profile(object o)
        {
            byte value = (byte)o;
            if (value > MaxValue)
                MaxValue = value;
        }

        public override string GetValue() { return MaxValue.ToString(); }
    }

    public class MaxDecimal : ValueProfiler
    {
        private Decimal MaxValue = Decimal.MinValue;

        public override void Profile(object o)
        {
            Decimal value = (Decimal)o;
            if (value > MaxValue)
                MaxValue = value;
        }

        public override string GetValue() { return MaxValue.ToString(); }
    }

    #endregion

    class ColumnProfilerMin : ColumnProfilerBase
    {
        private ValueProfiler valueProfiler;

        public override string GetProfileType() { return "MIN"; }
        public override string GetProfileValue() { return valueProfiler.GetValue(); }

        public override bool CanProfile()
        {
            return ColumnInfo.DataType == DataType.DT_I4
                   || ColumnInfo.DataType == DataType.DT_UI1
                   || ColumnInfo.DataType == DataType.DT_CY;
        }

        public override void Prepare()
        {
            if (ColumnInfo.DataType == DataType.DT_I4)
                valueProfiler = new MinInt();
            else if (ColumnInfo.DataType == DataType.DT_UI1)
                valueProfiler = new MinByte();
            else if (ColumnInfo.DataType == DataType.DT_CY)
                valueProfiler = new MinDecimal();
        }

        public override void Profile(PipelineBuffer buffer)
        {
            valueProfiler.Profile(buffer[ColumnIndex]);
        }
    };

    class ColumnProfilerMax : ColumnProfilerBase
    {
        private ValueProfiler valueProfiler;

        public override string GetProfileType() { return "MAX"; }
        public override string GetProfileValue() { return valueProfiler.GetValue(); }

        public override bool CanProfile()
        {
            return ColumnInfo.DataType == DataType.DT_I4
                   || ColumnInfo.DataType == DataType.DT_UI1
                   || ColumnInfo.DataType == DataType.DT_CY;
        }

        public override void Prepare()
        {
            if (ColumnInfo.DataType == DataType.DT_I4)
                valueProfiler = new MaxInt();
            else if (ColumnInfo.DataType == DataType.DT_UI1)
                valueProfiler = new MaxByte();
            else if (ColumnInfo.DataType == DataType.DT_CY)
                valueProfiler = new MaxDecimal();
        }

        public override void Profile(PipelineBuffer buffer)
        {
            valueProfiler.Profile(buffer[ColumnIndex]);
        }
    };
}
